@@ -15,8 +15,10 @@
 #
 
 import asyncio
+from itertools import groupby
 import json
 import logging
+from operator import itemgetter
 
 from aiohomekit.controller.pairing import AbstractPairing
 from aiohomekit.exceptions import (
@@ -32,7 +34,7 @@ from aiohomekit.http import HttpContentTypes
 from aiohomekit.model.characteristics import CharacteristicsTypes
 from aiohomekit.model.services import ServicesTypes
 from aiohomekit.protocol import error_handler
-from aiohomekit.protocol.statuscodes import HapStatusCodes
+from aiohomekit.protocol.statuscodes import to_status_code
 from aiohomekit.protocol.tlv import TLV
 
 from .connection import SecureHomeKitConnection
@@ -40,6 +42,9 @@ from .connection import SecureHomeKitConnection
 logger = logging.getLogger(__name__)
 
 
+EMPTY_EVENT = {}
+
+
 def format_characteristic_list(data):
     tmp = {}
     for c in data["characteristics"]:
@@ -50,7 +55,7 @@ def format_characteristic_list(data):
         if "status" in c and c["status"] == 0:
             del c["status"]
         if "status" in c and c["status"] != 0:
-            c["description"] = HapStatusCodes[c["status"]]
+            c["description"] = to_status_code(c["status"]).description
         tmp[key] = c
     return tmp
 
@@ -74,8 +79,9 @@ class IpPairing(AbstractPairing):
         self.supports_subscribe = True
 
     def event_received(self, event):
-        event = format_characteristic_list(event)
+        self._callback_listeners(format_characteristic_list(event))
 
+    def _callback_listeners(self, event):
         for listener in self.listeners:
             try:
                 listener(event)
@@ -86,6 +92,9 @@ class IpPairing(AbstractPairing):
         if not secure:
             return
 
+        # Let our listeners know the connection is available again
+        self._callback_listeners(EMPTY_EVENT)
+
         if self.subscriptions:
             await self.subscribe(self.subscriptions)
 
@@ -220,7 +229,7 @@ class IpPairing(AbstractPairing):
             await self.list_accessories_and_characteristics()
 
         url = "/characteristics?id=" + ",".join(
-            [str(x[0]) + "." + str(x[1]) for x in characteristics]
+            str(x[0]) + "." + str(x[1]) for x in characteristics
         )
         if include_meta:
             url += "&meta=1"
@@ -267,7 +276,7 @@ class IpPairing(AbstractPairing):
             data = {
                 (d["aid"], d["iid"]): {
                     "status": d["status"],
-                    "description": HapStatusCodes[d["status"]],
+                    "description": to_status_code(d["status"]).description,
                 }
                 for d in response["characteristics"]
             }
@@ -292,30 +301,12 @@ class IpPairing(AbstractPairing):
             )
             return {}
 
-        data = []
-        for (aid, iid) in characteristics:
-            data.append({"aid": aid, "iid": iid, "ev": True})
-
-        data = {"characteristics": data}
-
-        tmp = {}
-
         try:
-            response = await self.connection.put_json("/characteristics", data)
+            return await self._update_subscriptions(characteristics, True)
         except AccessoryDisconnectedError:
             self.supports_subscribe = False
             return {}
 
-        if response:
-            for row in response.get("characteristics", []):
-                id_tuple = (row["aid"], row["iid"])
-                tmp[id_tuple] = {
-                    "status": row["status"],
-                    "description": HapStatusCodes[row["status"]],
-                }
-
-        return tmp
-
     async def unsubscribe(self, characteristics):
         if not self.connection.is_connected:
             # If not connected no need to unsubscribe
@@ -323,30 +314,39 @@ class IpPairing(AbstractPairing):
             return {}
 
         await self._ensure_connected()
-
-        data = []
-        for (aid, iid) in characteristics:
-            data.append({"aid": aid, "iid": iid, "ev": False})
-
-        data = {"characteristics": data}
-
-        response = await self.connection.put_json("/characteristics", data)
-
         char_set = set(characteristics)
-        tmp = {}
-
-        if response:
-            for row in response:
-                id_tuple = (row["aid"], row["iid"])
-                tmp[id_tuple] = {
-                    "status": row["status"],
-                    "description": HapStatusCodes[row["status"]],
-                }
-                char_set.discard(id_tuple)
+        status = await self._update_subscriptions(characteristics, False)
+        for id_tuple in status:
+            char_set.discard(id_tuple)
 
         await super().unsubscribe(char_set)
+        return status
 
-        return tmp
+    async def _update_subscriptions(self, characteristics, ev):
+        """Subscribe or unsubscribe to characteristics."""
+        status = {}
+        # We do one aid at a time to match what iOS does
+        # even though its inefficient
+        # https://github.com/home-assistant/core/issues/37996
+
+        for _, aid_iids in groupby(characteristics, key=itemgetter(0)):
+            response = await self.connection.put_json(
+                "/characteristics",
+                {
+                    "characteristics": [
+                        {"aid": aid, "iid": iid, "ev": ev} for aid, iid in aid_iids
+                    ]
+                },
+            )
+            if response:
+                # An empty body is a success response
+                for row in response.get("characteristics", []):
+                    status[(row["aid"], row["iid"])] = {
+                        "status": row["status"],
+                        "description": to_status_code(row["status"]).description,
+                    }
+
+        return status
 
     async def identify(self):
         """
